pub struct CreditRegistrationHistoryPoint {
pub state: CreditRegistrationState,
pub count: i32,
pub entered_count: i32,
pub left_count: i32,
}Expand description
One state’s depth and flow on one day.
Fields
state: CreditRegistrationStatecount: i32Rows in the state when the snapshot was taken, once that day.
entered_count: i32Transitions into and out of the state during that UTC day. A self-transition is neither.
left_count: i32Trait Implementations
Sourceimpl Clone for CreditRegistrationHistoryPoint
impl Clone for CreditRegistrationHistoryPoint
Sourcefn clone(&self) -> CreditRegistrationHistoryPoint
fn clone(&self) -> CreditRegistrationHistoryPoint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CreditRegistrationHistoryPoint
impl ComposeSchema for CreditRegistrationHistoryPoint
Sourceimpl<'de> Deserialize<'de> for CreditRegistrationHistoryPoint
impl<'de> Deserialize<'de> for CreditRegistrationHistoryPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreditRegistrationHistoryPoint
impl PartialEq for CreditRegistrationHistoryPoint
Sourcefn eq(&self, other: &CreditRegistrationHistoryPoint) -> bool
fn eq(&self, other: &CreditRegistrationHistoryPoint) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CreditRegistrationHistoryPoint
impl ToSchema for CreditRegistrationHistoryPoint
impl StructuralPartialEq for CreditRegistrationHistoryPoint